@@ -1,5 +1,12 @@
-/* ansi2knr.c */
-/* Convert ANSI C function definitions to K&R ("traditional C") syntax */
+/* $Id: ansi2knr.c,v 1.2 1998/07/12 09:39:24 src Exp $
+ *
+ * Convert ANSI C function definitions to K&R ("traditional C") syntax 
+ *
+ * $Log: ansi2knr.c,v $
+ * Revision 1.2  1998/07/12 09:39:24  src
+ * NewsX version 1.0
+ *
+ */
 
 /*
 ansi2knr is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -40,9 +47,9 @@ program under the GPL.
  * These algorithms ignore whitespace and comments, except that
  * the function name must be the first thing on the line.
  * The following constructs will confuse it:
- *	- Any other construct that starts at the left margin and
- *	    follows the above syntax (such as a macro or function call).
- *	- Some macros that tinker with the syntax of the function header.
+ *      - Any other construct that starts at the left margin and
+ *          follows the above syntax (such as a macro or function call).
+ *      - Some macros that tinker with the syntax of the function header.
  */
 
 /*
@@ -141,7 +148,7 @@ program under the GPL.
  * Compensate for this here.
  */
 #ifdef isascii
-#  undef HAVE_ISASCII		/* just in case */
+#  undef HAVE_ISASCII           /* just in case */
 #  define HAVE_ISASCII 1
 #else
 #endif
@@ -173,8 +180,8 @@ int
 main(argc, argv)
     int argc;
     char *argv[];
-{	FILE *in, *out;
-#define bufsize 5000			/* arbitrary size */
+{       FILE *in, *out;
+#define bufsize 5000                    /* arbitrary size */
 	char *buf;
 	char *line;
 	char *more;
@@ -199,37 +206,37 @@ main(argc, argv)
 	/*
 	 * In previous versions, ansi2knr did not convert function 
 	 * definitions with the type declarations on the same line, e.g.
-	 *	    static int fn(int a);		
-	 *	    static int *fn(int a);		
-	 *	    static char [] fn(int a);		
+	 *          static int fn(int a);               
+	 *          static int *fn(int a);              
+	 *          static char [] fn(int a);           
 	 * The restriction that the first character on the line must be
 	 * alpha still applies. The --notypedecl switch disables this.
 	 */
 	int convert_typedecl = 1;
 
 	if ( argc > 1 && argv[1][0] == '-' )
-	  {	if ( strcmp(argv[1], "--varargs")==0 )
-		  {	convert_varargs = 1;
+	  {     if ( strcmp(argv[1], "--varargs")==0 )
+		  {     convert_varargs = 1;
 			argc--;
 			argv++;
 		  }
 		else if ( strcmp(argv[1], "--novarargs")==0 )
-		  {	convert_varargs = 0;
+		  {     convert_varargs = 0;
 			argc--;
 			argv++;
 		  }
 		else if ( strcmp(argv[1], "--noprototypes")==0 )
-		  {	convert_prototypes = 0;
+		  {     convert_prototypes = 0;
 			argc--;
 			argv++;
 		  }
 		else if ( strcmp(argv[1], "--notypedecl")==0 )
-		  {	convert_typedecl = 0;
+		  {     convert_typedecl = 0;
 			argc--;
 			argv++;
 		  }
 		else
-		  {	fprintf(stderr, "Unrecognized switch: %s\n", argv[1]);
+		  {     fprintf(stderr, "Unrecognized switch: %s\n", argv[1]);
 			exit(1);
 		  }
 	  }
@@ -262,16 +269,16 @@ main(argc, argv)
 	line = buf;
 	while ( fgets(line, (unsigned)(buf + bufsize - line), in) != NULL )
 	   {
-test:		line += strlen(line);
+test:           line += strlen(line);
 		switch ( test1(buf,convert_prototypes,convert_typedecl) )
 		   {
-		case 2: 		/* a function header */
+		case 2:                 /* a function header */
 			convert1(buf, out, 1, convert_varargs);
 			break;
-		case 1: 		/* a function */
+		case 1:                 /* a function */
 			/* Check for a { at the start of the next line. */
 			more = ++line;
-f:			if ( line >= buf + (bufsize - 1) ) /* overflow check */
+f:                      if ( line >= buf + (bufsize - 1) ) /* overflow check */
 			  goto wl;
 			if ( fgets(line, (unsigned)(buf + bufsize - line), in) == NULL )
 			  goto wl;
@@ -296,12 +303,12 @@ f:			if ( line >= buf + (bufsize - 1) ) /* overflow check */
 			    goto test;
 			  }
 			break;
-		case -1:		/* maybe the start of a function */
+		case -1:                /* maybe the start of a function */
 			if ( line != buf + (bufsize - 1) ) /* overflow check */
 			  continue;
 			/* falls through */
-		default:		/* not a function */
-wl:			fputs(buf, out);
+		default:                /* not a function */
+wl:                     fputs(buf, out);
 			break;
 		   }
 		line = buf;
@@ -318,16 +325,16 @@ wl:			fputs(buf, out);
 char *
 skipspace(p, dir)
     register char *p;
-    register int dir;			/* 1 for forward, -1 for backward */
-{	for ( ; ; )
-	   {	while ( is_space(*p) )
+    register int dir;                   /* 1 for forward, -1 for backward */
+{       for ( ; ; )
+	   {    while ( is_space(*p) )
 		  p += dir;
 		if ( !(*p == '/' && p[dir] == '*') )
 		  break;
 		p += dir;  p += dir;
 		while ( !(*p == '*' && p[dir] == '/') )
-		   {	if ( *p == 0 )
-			  return p;	/* multi-line comment?? */
+		   {    if ( *p == 0 )
+			  return p;     /* multi-line comment?? */
 			p += dir;
 		   }
 		p += dir;  p += dir;
@@ -343,7 +350,7 @@ int
 writeblanks(start, end)
     char *start;
     char *end;
-{	char *p;
+{       char *p;
 	for ( p = start; p < end; p++ )
 	  if ( *p != '\r' && *p != '\n' )
 	    *p = ' ';
@@ -354,32 +361,32 @@ writeblanks(start, end)
  * Test whether the string in buf is a function definition.
  * The string may contain and/or end with a newline.
  * Return as follows:
- *	0 - definitely not a function definition;
- *	1 - definitely a function definition;
- *	2 - definitely a function prototype;
- *	-1 - may be the beginning of a function definition,
- *		append another line and look again.
+ *      0 - definitely not a function definition;
+ *      1 - definitely a function definition;
+ *      2 - definitely a function prototype;
+ *      -1 - may be the beginning of a function definition,
+ *              append another line and look again.
  */
 int
 test1(buf,convert_prototypes,convert_typedecl)
     char *buf;
     int convert_prototypes;
     int convert_typedecl;
-{	register char *p = buf;
+{       register char *p = buf;
 	char *bend;
 	char *endfn;
 	int contin;
 	int more;
 
 	if ( !isidfirstchar(*p) )
-	  return 0;		/* no name at left margin */
+	  return 0;             /* no name at left margin */
 	bend = skipspace(buf + strlen(buf) - 1, -1);
 	switch ( *bend )
 	   {
 	   case ';': contin = convert_prototypes ? 2 : 0; break;
 	   case ')': contin = 1; break;
-	   case '{': return 0;		/* not a function */
-	   case '}': return 0;		/* not a function */
+	   case '{': return 0;          /* not a function */
+	   case '}': return 0;          /* not a function */
 	   default: contin = -1;
 	   }
 	while ( isidchar(*p) )
@@ -389,15 +396,15 @@ test1(buf,convert_prototypes,convert_typedecl)
 	/* Check that the apparent function name isn't a keyword. */
 	/* We only need to check for keywords that could be followed */
 	/* by a left parenthesis (which, unfortunately, is most of them). */
-	if ( isreserved(buf,endfn) )	
-	  return 0;			/* is a keyword, forget it */
+	if ( isreserved(buf,endfn) )    
+	  return 0;                     /* is a keyword, forget it */
 
 	p = skipspace(p, 1);
 
-	if (convert_typedecl)	    
+	if (convert_typedecl)       
 	  {
 		/* it might be a type definition */
-		int more = isreserved2(buf,endfn);		    
+		int more = isreserved2(buf,endfn);                  
 
 		while (*p != '(') {
 	
@@ -409,7 +416,7 @@ test1(buf,convert_prototypes,convert_typedecl)
 				do
 				  ++p;
 				while ( isidchar(*p) );
-				if ( isreserved(buf2,p) )	
+				if ( isreserved(buf2,p) )       
 				  return 0; /* strange */
 
 				more = isreserved2(buf2,p); 
@@ -440,12 +447,12 @@ test1(buf,convert_prototypes,convert_typedecl)
 	else
 	  {
 		if ( *p != '(' || isreserved2(buf,endfn) )
-		  return 0;		/* we wont' have this */
+		  return 0;             /* we wont' have this */
 	  }
 
 	p = skipspace(p+1, 1);
 	if ( *p == ')' )
-	  return 0;		/* no parameters: we need not bother */
+	  return 0;             /* no parameters: we need not bother */
 
 	return contin;
 }
@@ -455,8 +462,8 @@ int
 isreserved(buf,bufend)
     char *buf;
     char *bufend;
-{	static char *words[] =
-	   {	"asm", "do", "case", "continue", "default", "for", "if",
+{       static char *words[] =
+	   {    "asm", "do", "case", "continue", "default", "for", "if",
 		"return", "sizeof", "switch", "typedef", "while", 0
 	   };
 	return isonlist(buf,bufend,words);
@@ -467,8 +474,8 @@ int
 isreserved2(buf,bufend)
     char *buf;
     char *bufend;
-{	static char *words[] =
-	   {	"auto", "char", "const", "double", "extern", "float",
+{       static char *words[] =
+	   {    "auto", "char", "const", "double", "extern", "float",
 		"int", "long", "register", "short", "signed", "static",
 		"struct", "unsigned", "void", "volatile", 0
 	   };
@@ -487,8 +494,8 @@ isonlist(buf,bufend,words)
 	int len = bufend - buf;
 
 	while ( (kp = *key) != 0 )
-	   {	if ( strlen(kp) == len && strncmp(kp, buf, len)==0 )
-		  return 1;		/* name is a keyword */
+	   {    if ( strlen(kp) == len && strncmp(kp, buf, len)==0 )
+		  return 1;             /* name is a keyword */
 		key++;
 	   }
 	return 0;
@@ -499,16 +506,16 @@ int
 convert1(buf, out, header, convert_varargs)
     char *buf;
     FILE *out;
-    int header; 		/* Boolean */
-    int convert_varargs;	/* Boolean */
-{	char *endfn;
+    int header;                 /* Boolean */
+    int convert_varargs;        /* Boolean */
+{       char *endfn;
 	register char *p;
 	/*
 	 * The breaks table contains pointers to the beginning and end
 	 * of each argument.
 	 */
 	char **breaks;
-	unsigned num_breaks = 2;	/* for testing */
+	unsigned num_breaks = 2;        /* for testing */
 	char **btop;
 	char **bp;
 	char **ap;
@@ -518,10 +525,10 @@ convert1(buf, out, header, convert_varargs)
 	/* is called strchr or index, so we open-code it here. */
 	for ( endfn = buf; *(endfn++) != '('; )
 	  ;
-top:	p = endfn;
+top:    p = endfn;
 	breaks = (char **)malloc(sizeof(char *) * num_breaks * 2);
 	if ( breaks == 0 )
-	   {	/* Couldn't allocate break table, give up */
+	   {    /* Couldn't allocate break table, give up */
 		fprintf(stderr, "Unable to allocate break table!\n");
 		fputs(buf, out);
 		return -1;
@@ -530,13 +537,13 @@ top:	p = endfn;
 	bp = breaks;
 	/* Parse the argument list */
 	do
-	   {	int level = 0;
+	   {    int level = 0;
 		char *lp = NULL;
 		char *rp;
 		char *end = NULL;
 
 		if ( bp >= btop )
-		   {	/* Filled up break table. */
+		   {    /* Filled up break table. */
 			/* Allocate a bigger one and start over. */
 			free((char *)breaks);
 			num_breaks <<= 1;
@@ -545,7 +552,7 @@ top:	p = endfn;
 		*bp++ = p;
 		/* Find the end of the argument */
 		for ( ; end == NULL; p++ )
-		   {	switch(*p)
+		   {    switch(*p)
 			   {
 			   case ',':
 				if ( !level ) end = p;
@@ -568,17 +575,17 @@ top:	p = endfn;
 		/* Erase any embedded prototype parameters. */
 		if ( lp )
 		  writeblanks(lp + 1, rp);
-		p--;			/* back up over terminator */
+		p--;                    /* back up over terminator */
 		/* Find the name being declared. */
 		/* This is complicated because of procedure and */
 		/* array modifiers. */
 		for ( ; ; )
-		   {	p = skipspace(p - 1, -1);
+		   {    p = skipspace(p - 1, -1);
 			switch ( *p )
 			   {
-			   case ']':	/* skip array dimension(s) */
-			   case ')':	/* skip procedure args OR name */
-			   {	int level = 1;
+			   case ']':    /* skip array dimension(s) */
+			   case ')':    /* skip procedure args OR name */
+			   {    int level = 1;
 				while ( level )
 				 switch ( *--p )
 				   {
@@ -589,7 +596,7 @@ top:	p = endfn;
 				   }
 			   }
 				if ( *p == '(' && *skipspace(p + 1, 1) == '*' )
-				   {	/* We found the name being declared */
+				   {    /* We found the name being declared */
 					while ( !isidfirstchar(*p) )
 					  p = skipspace(p, 1) + 1;
 					goto found;
@@ -599,13 +606,13 @@ top:	p = endfn;
 				goto found;
 			   }
 		   }
-found:		if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
-		  {	if ( convert_varargs )
-			  {	*bp++ = "va_alist";
+found:          if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
+		  {     if ( convert_varargs )
+			  {     *bp++ = "va_alist";
 				vararg = p-2;
 			  }
 			else
-			  {	p++;
+			  {     p++;
 				if ( bp == breaks + 1 ) /* sole argument */
 				  writeblanks(breaks[0], p);
 				else
@@ -614,7 +621,7 @@ found:		if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
 			  }
 		   }
 		else
-		   {	while ( isidchar(*p) ) p--;
+		   {    while ( isidchar(*p) ) p--;
 			*bp++ = p+1;
 		   }
 		p = end;
@@ -623,11 +630,11 @@ found:		if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
 	*bp = p;
 	/* Make a special check for 'void' arglist */
 	if ( bp == breaks+2 )
-	   {	p = skipspace(breaks[0], 1);
+	   {    p = skipspace(breaks[0], 1);
 		if ( !strncmp(p, "void", 4) )
-		   {	p = skipspace(p+4, 1);
+		   {    p = skipspace(p+4, 1);
 			if ( p == breaks[2] - 1 )
-			   {	bp = breaks;	/* yup, pretend arglist is empty */
+			   {    bp = breaks;    /* yup, pretend arglist is empty */
 				writeblanks(breaks[0], p + 1);
 			   }
 		   }
@@ -637,14 +644,14 @@ found:		if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
 	while ( p != endfn ) putc(*p, out), p++;
 	/* Put out the declaration. */
 	if ( header )
-	  {	fputs(");", out);
+	  {     fputs(");", out);
 		for ( p = breaks[0]; *p; p++ )
 		  if ( *p == '\r' || *p == '\n' )
 		    putc(*p, out);
 	  }
 	else
-	  {	for ( ap = breaks+1; ap < bp; ap += 2 )
-		  {	p = *ap;
+	  {     for ( ap = breaks+1; ap < bp; ap += 2 )
+		  {     p = *ap;
 			while ( isidchar(*p) )
 			  putc(*p, out), p++;
 			if ( ap < bp - 1 )
@@ -655,9 +662,9 @@ found:		if ( *p == '.' && p[-1] == '.' && p[-2] == '.' )
 		for ( ap = breaks+2; ap <= bp; ap += 2 )
 		  (*ap)[-1] = ';';
 		if ( vararg != 0 )
-		  {	*vararg = 0;
-			fputs(breaks[0], out);		/* any prior args */
-			fputs("va_dcl", out);		/* the final arg */
+		  {     *vararg = 0;
+			fputs(breaks[0], out);          /* any prior args */
+			fputs("va_dcl", out);           /* the final arg */
 			fputs(bp[0], out);
 		  }
 		else
