@@ -1,10 +1,17 @@
-/*  VER 018  TAB P   $Id: msgid.c,v 1.2 1997/08/14 13:39:44 src Exp $
+/*  VER 021  TAB P   $Id: msgid.c,v 1.5 1998/09/09 07:32:12 src Exp $
  *
  *  handle the message IDs
  *  to ensure we don't read a message twice
  *
  *  copyright 1996, 1997 Egil Kvaleberg, egil@kvaleberg.no
  *  the GNU General Public License applies
+ *
+ *  $Log: msgid.c,v $
+ *  Revision 1.5  1998/09/09 07:32:12  src
+ *  Version 1.1
+ *
+ *  Revision 1.4  1998/07/12 09:39:29  src
+ *  newsx version 1.0
  */
 
 #include "common.h"
@@ -36,7 +43,7 @@ new_msgid(char *msgid)
     /* find it first.. */
     for (mp = messageids[h]; mp; mp = mp->next) {
 	if (strcmp(mp->name,msgid)==0) {
-	    log_msg(L_DEBUG4,"msgid %s fetched already",msgid);
+	    log_msg(L_DEBUGMORE,"msgid %s fetched already",msgid);
 	    return 0;
 	}
     }
